@@ -24,7 +24,6 @@ class ObjectRickler:
         - `tuple` types are deconstructed as lists
 
     """
-
     def __init__(self):
         self.pat = re.compile(r'^( )*')
 
@@ -77,6 +76,7 @@ class ObjectRickler:
             for s in source_lines[1:]:
                 source = f'{source}{s[length:]}'
 
+
             return {
                 'type': 'function',
                 'name': name,
@@ -572,9 +572,9 @@ class Rickle(BaseRickle):
     def _iternalize(self, dictionary: dict, deep: bool, **init_args):
         for k, v in dictionary.items():
             if isinstance(v, dict):
-
                 lotse_names = {'condition', 'is_applicable', 'determine_applicability', 'accept', 'reject',
-                               'preview_start', 'preview_end', 'generate_suggestion_content', 'initialize'}
+                               'preview_start', 'preview_end', 'generate_suggestion_content', 'initialize',
+                               'filter_actions'}
                 if k in lotse_names:
                     name = k
                     load = v['load']
@@ -605,18 +605,18 @@ class Rickle(BaseRickle):
                     self.add_module_import(name=k,
                                            imports=v['import'])
                     continue
-                if 'file_path' in v.keys():
-                    self.add_from_file(name=k,
-                                       file_path=v['file_path'],
-                                       load_as_rick=v.get('load_as_rick', True),
-                                       deep=v.get('deep', True),
-                                       load_lambda=v.get('load_lambda', True),
-                                       is_binary=v.get('is_binary', False),
-                                       encoding=v.get('encoding', 'utf-8'))
-                    continue
                 if 'type' in v.keys() and v['type'] == 'from_csv':
+                    path = os.path.join(init_args['path'], v['file_path']) if 'path' in init_args else v['file_path']
                     self.add_csv_file(name=k,
-                                      file_path=v['file_path'],
+                                      file_path=path,
+                                      fieldnames=v.get('fieldnames', None),
+                                      load_as_rick=v.get('load_as_rick', False),
+                                      encoding=v.get('encoding', 'utf-8'),
+                                      )
+                    continue
+                if 'source' in v.keys() and 'load' in v.keys and v['load'] == 'csv':
+                    self.add_csv_file(name=k,
+                                      file_path=v['source'],
                                       fieldnames=v.get('fieldnames', None),
                                       load_as_rick=v.get('load_as_rick', False),
                                       encoding=v.get('encoding', 'utf-8'))
@@ -632,6 +632,15 @@ class Rickle(BaseRickle):
                                            deep=v.get('deep', False),
                                            expected_http_status=v.get('expected_http_status', 200))
                     continue
+                if 'file_path' in v.keys():
+                    self.add_from_file(name=k,
+                                       file_path=v['file_path'],
+                                       load_as_rick=v.get('load_as_rick', True),
+                                       deep=v.get('deep', True),
+                                       load_lambda=v.get('load_lambda', True),
+                                       is_binary=v.get('is_binary', False),
+                                       encoding=v.get('encoding', 'utf-8'))
+                    continue
                 if 'type' in v.keys() and v['type'] == 'html_page':
                     self.add_html_page(name=k,
                                        url=v['url'],
@@ -799,7 +808,6 @@ class Rickle(BaseRickle):
                 else:
                     exec('import {}'.format(i), globals())
         suffix: str = uuid.uuid4().hex
-        # print("METHOD:", is_method)
 
         args_string = ""
         if args and isinstance(args, dict):
@@ -825,7 +833,6 @@ class Rickle(BaseRickle):
         elif args and isinstance(args, list):
             arg_list = ['self'] if is_method else list()
             arg_list.extend(args)
-            # print("ARG LIST", arg_list)
 
             args_string = ','.join(args)
             func_string = 'lambda {args_list}: {name}({args})'.format(
@@ -848,10 +855,6 @@ class Rickle(BaseRickle):
         _load += load.replace("\n", "\n  ")
         exec(_load, globals())
 
-        # print("LOADING: \n", _load)
-        # print("\nFUNC: \n", func_string)
-        # print("\n=======================================\n")
-
         if return_function:
             return eval(func_string)
 
@@ -960,7 +963,7 @@ class Rickle(BaseRickle):
 
                 self._iternalize({name: l}, deep=True)
             else:
-                csv_file = csv.reader(file, dialect=dialect)
+                csv_file = csv.DictReader(file, dialect=dialect)
 
                 for row in csv_file:
                     l.append(row)
@@ -1100,6 +1103,7 @@ class Rickle(BaseRickle):
                           params: dict = None,
                           body: dict = None,
                           deep: bool = False,
+                          load_as_rick: bool = False,
                           load_lambda: bool = False,
                           expected_http_status: int = 200):
         """
@@ -1127,10 +1131,13 @@ class Rickle(BaseRickle):
 
         if r.status_code == expected_http_status:
             json_dict = r.json()
-            args = copy.copy(self.__init_args)
-            args['load_lambda'] = load_lambda
-            args['deep'] = deep
-            self.__dict__.update({name: Rickle(json_dict, **args)})
+            if load_as_rick:
+                args = copy.copy(self.__init_args)
+                args['load_lambda'] = load_lambda
+                args['deep'] = deep
+                self.__dict__.update({name: Rickle(json_dict, **args)})
+            else:
+                self.__dict__.update({name: json_dict})
         else:
             raise ValueError(f'Unexpected HTTP status code in response {r.status_code}')
         self.__meta_info[name] = {'type': 'api_json',
